abacusai.feature_group_export_download_url — AbacusAI documentation

# abacusai.feature_group_export_download_url

## Classes

`FeatureGroupExportDownloadUrl` | A Feature Group Export Download Url, which is used to download the feature group version

## Module Contents

class abacusai.feature_group_export_download_url.FeatureGroupExportDownloadUrl(client, downloadUrl=None, expiresAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Feature Group Export Download Url, which is used to download the feature group version

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - downloadUrl (str) – The URL of the download location.

    - expiresAt (str) – String representation of the ISO-8601 datetime when the URL expires.

  download_url
  expires_at
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict